@@ -6,6 +6,9 @@
 
 #include <R.h>
 
+/* Default for antialiasing */
+#define RGL_ANTIALIAS 8
+
 /* Set this to 1 to turn on glGetError testing */
 #define USE_GLGETERROR 0
 
@@ -28,4 +31,6 @@ void checkGLerror(const char *, int);
 #define CHECKGLERROR
 #endif
 
+
+
 #endif /* RGL_R_H */
